export type CaseSensitivity<T extends string> = string extends T ? string : T extends `${infer F1}${infer F2}${infer R}` ? `${Uppercase<F1> | Lowercase<F1>}${Uppercase<F2> | Lowercase<F2>}${CaseSensitivity<R>}` : T extends `${infer F}${infer R}` ? `${Uppercase<F> | Lowercase<F>}${CaseSensitivity<R>}` : "";
export interface ControlCommons {
    key?: string;
    displayName?: string;
    value?: string;
    mrnEntries?: {
        [key: string]: any;
    };
    hasChanged?: boolean;
    error?: {
        message: string;
    };
    required?: boolean;
    placeholder?: string;
    hasEdited?: "edited" | "not-edited" | undefined;
    "custom-attributes"?: CustomAttributes;
}
export type FormVisibility = "hidden" | "visible" | "expert" | {
    hideOnCondition: string;
};
export type GenAiPrompt = {
    displayValue: string;
    promptTemplate: string;
    profile?: string;
};
export type GenAiPrompts = GenAiPrompt[];
export interface CustomAttributes {
    media?: string;
    "mrn-ref"?: string;
    "mrn-ref-display-field"?: string;
    "mrn-ref-params"?: string;
    "mrn-ref-mrn-field"?: string;
    options?: InputFreeSoloOptions[];
    mrnPreview?: {
        displayField?: string;
        linkDisabled?: boolean;
    };
    submenu?: {
        icon?: string;
    };
    mrnSources?: MrnInputMultipleServices[];
    defaultValue?: string;
    defaultCollapseThreshold?: string;
    visibility?: {
        form?: FormVisibility;
        detailView?: "hidden" | "visible";
        table?: "hidden" | "visible";
    };
    editor?: "richtext" | "markdown" | "code" | "plate";
    viewer?: "html" | "markdown";
    tags?: string | string[];
    genAiPrompts?: GenAiPrompts;
    tooltip?: string;
    [key: string]: any;
}
export type MrnInputMultipleServices = {
    name: string;
    mrn: string;
    query: string;
    mrnField: string;
    displayField: string;
    [key: string]: any;
};
export interface GroupFormControl extends ControlCommons {
    control: "group";
    controls: FormControls;
}
export interface InputFormControl extends ControlCommons {
    control: "input";
    type: "plain" | "html" | "hex" | "color" | "mrn" | "url" | "date" | "time" | "datetime" | "number" | "email" | "password" | "geolocation";
    placeholder?: string;
    pattern?: string;
    minLength?: number;
    maxLength?: number;
    step?: number;
}
export interface InputFreeSoloOptions {
    value: string;
    text?: string;
    tooltip?: string;
    default?: "true" | "false" | undefined;
}
export interface TextareaFormControl extends ControlCommons {
    control: "textarea";
    type: "plain" | "html" | "json";
}
export interface CheckboxFormControl extends ControlCommons {
    control: "checkbox";
    selected?: boolean;
}
export interface SelectFormControlOption extends Omit<ControlCommons, "displayName"> {
    value: string;
    text: string;
    phone?: string;
    selected?: boolean;
}
export interface SelectFormControl extends ControlCommons {
    control: "select";
    options?: SelectFormControlOption[];
    multiple?: boolean;
}
export interface MrnInputServiceSelection {
}
export interface MultiSelectFormControl extends Omit<SelectFormControl, "value"> {
    value?: string | string[];
}
export interface ListFormControl extends ControlCommons {
    control: "list";
    items?: FormControls[];
    required?: boolean;
    template: FormControls;
}
export type Control = "input" | "textarea" | "checkbox" | "select" | "list";
export type ControlType = "plain" | "html" | "hex" | "color" | "mrn" | "url" | "date" | "time" | "datetime" | "number" | "email" | "password" | "geolocation" | "json";
export type FormControl = InputFormControl | TextareaFormControl | CheckboxFormControl | SelectFormControl | MultiSelectFormControl | ListFormControl | GroupFormControl;
export interface FormControls {
    [key: string]: FormControl;
}
type fileUploaderEndpoint = {
    url: string;
    name: string;
};
export type FileUploaderConfig = {
    info?: string;
    endpoints?: fileUploaderEndpoint[];
    language?: string;
    previewUrl?: (url: string) => Promise<any>;
    authorizationHeader?: (url: string, method: string) => string;
};
export interface FormBuilderConfigLink {
    href: string;
    rel: string;
    text: string;
}
export interface FormBuilderConfig {
    method: "POST" | "GET";
    links: FormBuilderConfigLink[];
    error?: {
        message: string;
    };
    items: FormControls;
}
export type OnChangeValueType = {
    value?: string | string[] | number;
    [key: string]: any;
};
export interface resolveUrl {
    (mrn: string, params: string, opts: any): Promise<any>;
}
export type MessageType = string;
export type MessageStatus = "error" | "success";
export interface PostMessageProps {
    message: MessageType;
    profile: string;
}
export type PostMessageResponse = {
    message: MessageType;
    model: string;
    usage: {
        answer: string;
        prompt: string;
        total: string;
    };
    status: MessageStatus;
};
export {};
